"use strict";
var graphql_1 = require("graphql");
var model_handler_1 = require("./model-handler");
var operation_handler_1 = require("./operation-handler");
var fragment_handler_1 = require("./fragment-handler");
exports.prepareCodegen = function (schema, document, primitivesMap) {
    if (primitivesMap === void 0) { primitivesMap = {}; }
    var models = [];
    var documents = [];
    var typesMap = schema.getTypeMap();
    Object.keys(typesMap).forEach(function (typeName) {
        models.push(model_handler_1.handleType(primitivesMap, typesMap[typeName]));
    });
    document.definitions.forEach(function (definition) {
        switch (definition.kind) {
            case graphql_1.Kind.OPERATION_DEFINITION:
                documents.push(operation_handler_1.handleOperation(schema, definition, primitivesMap));
                break;
            case graphql_1.Kind.FRAGMENT_DEFINITION:
                documents.push(fragment_handler_1.handleFragment(schema, definition, primitivesMap));
                break;
            default:
                break;
        }
    });
    return {
        models: models.filter(function (item) { return item; }),
        documents: documents.filter(function (item) { return item; })
    };
};
//# sourceMappingURL=codegen.js.map