"use strict";
var definition_1 = require("graphql/type/definition");
var kinds_1 = require("graphql/language/kinds");
var utils_1 = require("./utils");
var pascalCase = require("pascal-case");
var typeFromAST_1 = require("graphql/utilities/typeFromAST");
exports.buildInnerModelsArray = function (schema, rootObject, selections, primitivesMap, appendTo, result) {
    if (result === void 0) { result = []; }
    (selections ? selections.selections : []).forEach(function (selectionNode) {
        switch (selectionNode.kind) {
            case kinds_1.FIELD:
                var fieldName = selectionNode.name.value;
                var propertyName = selectionNode.alias ? selectionNode.alias.value : fieldName;
                var field = utils_1.getFieldDef(rootObject, selectionNode);
                var rawType = field.type;
                var actualType = definition_1.getNamedType(rawType);
                if (actualType instanceof definition_1.GraphQLObjectType) {
                    var modelName = utils_1.handleNameDuplications(pascalCase(fieldName), result);
                    var model = {
                        name: modelName,
                        fields: [],
                        fragmentsUsed: [],
                        inlineFragments: []
                    };
                    result.push(model);
                    exports.buildInnerModelsArray(schema, actualType, selectionNode.selectionSet, primitivesMap, model, result);
                    if (!appendTo) {
                        // Means we are on the root object, and we need to create the Result interface
                        appendTo = {
                            name: 'Result',
                            fields: [],
                            fragmentsUsed: [],
                            inlineFragments: []
                        };
                        result.push(appendTo);
                    }
                    appendTo.fields.push({
                        name: propertyName,
                        type: modelName,
                        isArray: utils_1.isArray(rawType),
                        isRequired: utils_1.isRequired(rawType)
                    });
                }
                else {
                    appendTo.fields.push({
                        name: propertyName,
                        type: utils_1.getTypeName(primitivesMap, actualType),
                        isArray: utils_1.isArray(rawType),
                        isRequired: utils_1.isRequired(rawType)
                    });
                }
                break;
            case kinds_1.FRAGMENT_SPREAD:
                var fragmentName = selectionNode.name.value;
                appendTo.fragmentsUsed.push(pascalCase(fragmentName));
                appendTo.usingFragments = appendTo.fragmentsUsed.length > 0;
                break;
            case kinds_1.INLINE_FRAGMENT:
                var root = typeFromAST_1.typeFromAST(schema, selectionNode.typeCondition);
                var name_1 = selectionNode.typeCondition.name.value + 'InlineFragment';
                var fragmentModel = {
                    name: name_1,
                    fields: [],
                    fragmentsUsed: [],
                    inlineFragments: []
                };
                appendTo.inlineFragments.push({
                    typeName: name_1,
                    onModel: selectionNode.typeCondition.name.value,
                });
                appendTo.hasInlineFragments = appendTo.inlineFragments.length > 0;
                result.push(fragmentModel);
                exports.buildInnerModelsArray(schema, root, selectionNode.selectionSet, primitivesMap, fragmentModel, result);
                break;
            default:
                break;
        }
    });
    return result;
};
//# sourceMappingURL=inner-models-builer.js.map